@@ -77,7 +77,7 @@ class LIGAttributions(Attributions):
             )
 
     @property
-    def word_attributions(self):
+    def word_attributions(self) -> list:
         wa = []
         if len(self.attributions_sum) >= 1:
             for i, (word, attribution) in enumerate(
@@ -96,7 +96,7 @@ class LIGAttributions(Attributions):
         )
 
     def visualize_attributions(
-        self, pred_prob, pred_class, true_class, attr_class, text, all_tokens
+        self, pred_prob, pred_class, true_class, attr_class, all_tokens
     ):
 
         return viz.VisualizationDataRecord(
